==> jc-1.4.0.tar.gz: gnu/xml/libxmlj/dom/GnomeDOMStringList.h <==
// class gnu.xml.libxmlj.dom.GnomeDOMStringList

// class file dependencies
// @dep_class b5f9ac95ff1ede6d gnu_xml_libxmlj_dom_GnomeDOMStringList
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_libxmlj_dom_GnomeDOMStringList_H_
#define _JC_gnu_xml_libxmlj_dom_GnomeDOMStringList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$sub_refs	_jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$sub_nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$refs	_jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$object	_jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$object;

typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$vmethods	_jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$vtable	_jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$vtable;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$vtype	_jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$method$_init$7e8a2d8fd15238cb(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$object *, struct _jc_object_array *);

// Virtual methods
extern jboolean _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$method$contains$14daef07ea176c5a(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$object *, struct _jc_java_lang_String$object *);
extern jint _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$method$getLength$b9eaa8ec0a00f23d(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$method$item$6e119e3ba785706b(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$method_info$contains$14daef07ea176c5a;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$method_info$getLength$b9eaa8ec0a00f23d;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$method_info$item$6e119e3ba785706b;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$vmethods {
	jboolean	(*contains$14daef07ea176c5a)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$object *, struct _jc_java_lang_String$object *);
	jint	(*getLength$b9eaa8ec0a00f23d)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$object *);
	struct _jc_java_lang_String$object	*(*item$6e119e3ba785706b)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$object *, jint);
};

// Vtable
struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$vmethods	gnu_xml_libxmlj_dom_GnomeDOMStringList;
};

// Vtype
struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$sub_refs {
	_jc_object_array	*values;
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$refs {
    _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$sub_refs	gnu_xml_libxmlj_dom_GnomeDOMStringList;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeDOMStringList;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$object {
	_jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$vtype	*vtype;
	_jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$vtype _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_dom_GnomeDOMStringList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$class_object;

#endif	/* _JC_gnu_xml_libxmlj_dom_GnomeDOMStringList_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/libxmlj/dom/GnomeDOMStringList.h <==
// class gnu.xml.libxmlj.dom.GnomeDOMStringList

// class file dependencies
// @dep_class b5f9ac95ff1ede6d gnu_xml_libxmlj_dom_GnomeDOMStringList
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_libxmlj_dom_GnomeDOMStringList_H_
#define _JC_gnu_xml_libxmlj_dom_GnomeDOMStringList_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$sub_refs	_jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$sub_nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$refs	_jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$object	_jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$object;

typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$vmethods	_jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$vtable	_jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$vtable;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$vtype	_jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$method$_init$7e8a2d8fd15238cb(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$method$contains$14daef07ea176c5a(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$method$getLength$b9eaa8ec0a00f23d(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$method$item$6e119e3ba785706b(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$method_info$contains$14daef07ea176c5a;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$method_info$getLength$b9eaa8ec0a00f23d;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$method_info$item$6e119e3ba785706b;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$vmethods {
	jboolean	(*contains$14daef07ea176c5a)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	jint	(*getLength$b9eaa8ec0a00f23d)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*item$6e119e3ba785706b)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$vmethods	gnu_xml_libxmlj_dom_GnomeDOMStringList;
};

// Vtype
struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$sub_refs {
	_jc_object_array	*values;
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$refs {
    _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$sub_refs	gnu_xml_libxmlj_dom_GnomeDOMStringList;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeDOMStringList;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$object {
	_jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$vtype	*vtype;
	_jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$vtype _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_dom_GnomeDOMStringList, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_dom_GnomeDOMStringList$class_object;

#endif	/* _JC_gnu_xml_libxmlj_dom_GnomeDOMStringList_H_ */
